@@ -428,7 +428,7 @@ class ConstructWithProperties(
         :param props: -
         :param props2: -
         '''
-        jsii.create(ConstructWithProperties, self, [parent, name, props, props2])
+        jsii.create(self.__class__, self, [parent, name, props, props2])
 
 
 @jsii.interface(jsii_type="@seeebiii/projen-test.IBehaviorProperties")
@@ -479,7 +479,7 @@ class LambdaConstruct(
         :param parent: -
         :param name: -
         '''
-        jsii.create(LambdaConstruct, self, [parent, name])
+        jsii.create(self.__class__, self, [parent, name])
 
 
 @jsii.data_type(
